@@ -2,8 +2,8 @@
 @Author  : Likianta <likianta@foxmail.com>
 @Module  : lk_browser.py
 @Created : 2018-00-00
-@Updated : 2020-08-10
-@Version : 1.7.0
+@Updated : 2020-09-06
+@Version : 1.7.1
 @Desc    :
 """
 from os.path import exists
@@ -12,7 +12,6 @@ from time import sleep
 
 from requests import Response, Session
 
-from .lk_logger import lk
 from .read_and_write import loads as loads_file
 
 
@@ -123,8 +122,8 @@ class LKBrowser:
         """
         IN: cookies
                 str: 表示一个 cookies 文件的路径. 如果该路径以 '.txt' 结尾, 则使
-                 用 cook_cookies() 方法读取; 如果是以 '.json' 结尾, 则使用
-                 read_json() 方法. 最终目的是将其转化为 dict 类型.
+                    用 cook_cookies() 方法读取; 如果是以 '.json' 结尾, 则使用
+                    read_json() 方法. 最终目的是将其转化为 dict 类型.
                 dict: 可直接使用.
         OT: self.session.cookies (updated)
         """
@@ -154,13 +153,14 @@ class LKBrowser:
             传入三个及以上的值, 报错;
             不传入值, 则使用缺省值 0 ~ 3.
         注: 如果您需要睡眠毫秒级的时间, 请自己设计函数实现. LKBrowser 自带的睡眠
-         相关的方法不具备此功能. 提示:
-            from random import random
-            from time import sleep
-            
-            def _doze(m: float, n: float):
-                # e.g. m = 1.0, n = 1.5
-                sleep(round(m + random() * (n - m), 3))
+            相关的方法不具备此功能.
+            提示:
+                from random import random
+                from time import sleep
+                
+                def _doze(m: float, n: float):
+                    # e.g. m = 1.0, n = 1.5
+                    sleep(round(m + random() * (n - m), 3))
         """
         if len(sleepy) == 0:  # use default value
             self.sleepy = (0, 3)
@@ -191,7 +191,7 @@ class LKBrowser:
             if self.response.status_code == 200:
                 break
             else:
-                lk.logt('[W2912]', _retry_times, h='parent')
+                # lk.logt('[W2912]', _retry_times, h='parent')
                 continue
         
         self._check_status_code(additional_info=(url, params))
@@ -214,7 +214,7 @@ class LKBrowser:
             if self.response.status_code == 200:
                 break
             else:
-                lk.logt('[W2913]', _retry_times, h='parent')
+                # lk.logt('[W2913]', _retry_times, h='parent')
                 continue
         
         self._check_status_code(additional_info=(url, data))
@@ -224,7 +224,7 @@ class LKBrowser:
         """
         FIXME: maybe we should return response.text
         
-        example:
+        Example:
             1. smfile 图床:
                 filedata = {'smfile': open('123.png', 'rb)}
                 data = {'ssl': False, 'format': 'json'}
@@ -259,7 +259,7 @@ class LKBrowser:
     def download(self, url, ofile):
         """
         注: 此方法不检查下载文件的编码格式, 适用于下载图片, 音频, 视频, 资源文件
-         类数据. 如需下载离线网页, 请改用 self.save_page().
+            类数据. 如需下载离线网页, 请改用 self.save_page().
         参考:
             python 爬虫 requests 下载图片 - 稀里糊涂林老冷 - 博客园
             https://www.cnblogs.com/Lin-Yi/p/7640155.html
@@ -273,7 +273,7 @@ class LKBrowser:
                   source_encoding=None, target_encoding='utf-8'):
         """
         这是 self.download() 方法的特化版, 专门用于下载并调节下载文件的格式以
-         utf-8 (默认) 保存.
+            utf-8 (默认) 保存.
         ARGS:
             url: 要请求的网页 (只支持 GET 请求)
             ofile: 生成文件
@@ -296,8 +296,7 @@ class LKBrowser:
             )):
                 source_encoding = None
             else:
-                """
-                注意: 本方法对获取编码的方法进行了调整:
+                """ 注意: 本方法对获取编码的方法进行了调整:
                 1. 优先使用 chardet 预测的 encoding, 其次是 http headers 提供的
                    encoding 信息. 这样做的原因在于, 经发现国内的一些网站的 http
                    headers 提供的是错误的 encoding. 比如 http://www.most.gov.cn/
@@ -316,7 +315,7 @@ class LKBrowser:
         
         if source_encoding is None:
             # 出现这种情况, 说明网页没有给出编码信息, chardet 也无法预测. 通常意
-            #  味着此文件是 pdf, jpg, png 等类型的文件. 那么我们采用二进制写入.
+            # 味着此文件是 pdf, jpg, png 等类型的文件. 那么我们采用二进制写入.
             with open(ofile, 'wb') as f:
                 f.write(self.response.content)
         else:
